glue\_genes.glue\_single\_cell.anndata\_factory.read\_anndata
=============================================================

.. currentmodule:: glue_genes.glue_single_cell.anndata_factory

.. autofunction:: read_anndata